*Create SAS .sas7bdat data set;
libname ProjData "P:\ProjData";
libname out "P:\ProjData";
DATA ProjData.PurpleAirData;
    LENGTH
        location_id        8
        location         $ 8
        created_at         8
        entry_id           8
        PM1_0_CF_ATM_ug_m3   8
        PM2_5_CF_ATM_ug_m3   8
        PM10_0_CF_ATM_ug_m3   8
        UptimeMinutes      8
        ADC                8
        Temperature_F      8
        Humidity__         8
        Total_PM           8 
		Safe 			8;
    LABEL
        PM1_0_CF_ATM_ug_m3 = "PM1.0_CF_ATM_ug/m3"
        PM2_5_CF_ATM_ug_m3 = "PM2.5_CF_ATM_ug/m3"
        PM10_0_CF_ATM_ug_m3 = "PM10.0_CF_ATM_ug/m3"
        Humidity__       = "Humidity_%" ;
    FORMAT
        location_id      BEST1.
        location         $CHAR8.
        created_at       DATETIME21.2
        entry_id         BEST6.
        PM1_0_CF_ATM_ug_m3 BEST6.
        PM2_5_CF_ATM_ug_m3 BEST7.
        PM10_0_CF_ATM_ug_m3 BEST7.
        UptimeMinutes    BEST5.
        ADC              BEST3.
        Temperature_F    BEST4.
        Humidity__       BEST3.
        Total_PM         BEST7. 
		Safe 			 BEST1.;
    INFORMAT
        location_id      BEST1.
        location         $CHAR8.
        created_at       DATETIME21.
        entry_id         BEST6.
        PM1_0_CF_ATM_ug_m3 BEST6.
        PM2_5_CF_ATM_ug_m3 BEST7.
        PM10_0_CF_ATM_ug_m3 BEST7.
        UptimeMinutes    BEST5.
        ADC              BEST3.
        Temperature_F    BEST4.
        Humidity__       BEST3.
        Total_PM         BEST7. 
		Safe 			 BEST1.;
    INFILE 'P:\ProjData\PurpleAirDataCSV.csv'
        LRECL=32767
        FIRSTOBS=2
        ENCODING="WLATIN1"
        DLM='2c'x
        MISSOVER
        DSD ;
    INPUT
        location_id      : ?? BEST1.
        location         : $CHAR8.
        created_at       : ?? ANYDTDTM23.
        entry_id         : ?? BEST6.
        PM1_0_CF_ATM_ug_m3 : ?? COMMA6.
        PM2_5_CF_ATM_ug_m3 : ?? COMMA7.
        PM10_0_CF_ATM_ug_m3 : ?? COMMA7.
        UptimeMinutes    : ?? BEST5.
        ADC              : ?? BEST3.
        Temperature_F    : ?? BEST4.
        Humidity__       : ?? BEST3.
        Total_PM         : ?? COMMA7. 
		Safe			 : ?? BEST1.;
RUN;
*Add Binary DV;
data ProjData.PurpleAirData;
	set ProjData.PurpleAirData;
	if Total_PM < 50 then Safe=1;
	else Safe=0;
run;
data out.PurpleAirData;
set projdata.PurpleAirData;
run;
*Explore metadata;
proc contents data=projdata.PurpleAirData;
run;
*Look at frequencies;
proc freq data=projdata.PurpleAirData;
run;
proc freq data=projdata.PurpleAirData order=freq;
	tables entry_id / nocum nopercent;
run;
proc freq data=projdata.PurpleAirData order=freq;
	tables created_at / nocum nopercent;
run;
proc freq data=projdata.PurpleAirData order=freq;
	where Total_PM >= 50
	by location_id;
run;
*Look for errors;
proc univariate data=projdata.PurpleAirData;
run;
*Look at basic stats;
proc means data=projdata.PurpleAirData mean median mode min max range q1 q3 stddev skewness kurtosis;
	var ADC Created_At Humidity PM10_0_CF_ATM_ugm3 PM1_0_CF_ATM_ugm3 PM2_5_CF_ATM_ugm3 Total_PM Temperature_F Safe location_id;
run;
proc means data=projdata.PurpleAirData mean median mode min max range q1 q3 stddev skewness kurtosis;
	var ADC Created_At Humidity PM10_0_CF_ATM_ugm3 PM1_0_CF_ATM_ugm3 PM2_5_CF_ATM_ugm3 Total_PM Temperature_F Safe;
	class Location_ID;
run;
proc means data=projdata.PurpleAirData mean median mode min max range q1 q3 stddev skewness kurtosis;
	var PM10_0_CF_ATM_ugm3;
run;
proc means data=projdata.PurpleAirData mean median mode min max range q1 q3 stddev skewness kurtosis;
	var PM1_0_CF_ATM_ugm3 ;
run;
proc means data=projdata.PurpleAirData mean median mode min max range q1 q3 stddev skewness kurtosis;
	var PM2_5_CF_ATM_ugm3;
run;
proc means data=projdata.PurpleAirData mean median mode min max range q1 q3 stddev skewness kurtosis;
	var PM10_0_CF_ATM_ugm3;
	class Location_ID;
run;
proc means data=projdata.PurpleAirData mean median mode min max range q1 q3 stddev skewness kurtosis;
	var PM1_0_CF_ATM_ugm3;
	class Location_ID;
run;
proc means data=projdata.PurpleAirData mean median mode min max range q1 q3 stddev skewness kurtosis;
	var PM2_5_CF_ATM_ugm3;
	class Location_ID;
run;
proc univariate data=projdata.PurpleAirData;
	var ADC Created_At Humidity PM10_0_CF_ATM_ugm3 PM1_0_CF_ATM_ugm3 PM2_5_CF_ATM_ugm3 Total_PM Temperature_F;
	class Location_ID;
run;
proc univariate data=projdata.PurpleAirData;
	var PM10_0_CF_ATM_ugm3;
run;
proc univariate data=projdata.PurpleAirData;
	var PM1_0_CF_ATM_ugm3;
run;
proc univariate data=projdata.PurpleAirData;
	var PM2_5_CF_ATM_ugm3;
run;
*View histograms;
proc sgplot data=projdata.PurpleAirData;
	HISTOGRAM Total_PM;
run;
proc sgplot data=projdata.PurpleAirData;
	HISTOGRAM PM10_0_CF_ATM_ugm3; 
run;
proc sgplot data=projdata.PurpleAirData;
	HISTOGRAM PM1_0_CF_ATM_ugm3;
run;
proc sgplot data=projdata.PurpleAirData;
	HISTOGRAM PM2_5_CF_ATM_ugm3;
run;
*View Box Plots;
proc sgplot data=projdata.PurpleAirData;
	VBOX Total_PM;
run;
proc sgplot data=projdata.PurpleAirData;
	VBOX PM10_0_CF_ATM_ugm3;
run;
proc sgplot data=projdata.PurpleAirData;
	VBOX PM1_0_CF_ATM_ugm3;
run;
proc sgplot data=projdata.PurpleAirData;
	VBOX PM2_5_CF_ATM_ugm3;
run;
*looking closer at correlations;
proc corr data=projdata.PurpleAirData nosimple plots=matrix(nvar=all histogram);
	var ADC Created_At Humidity PM10_0_CF_ATM_ugm3 PM1_0_CF_ATM_ugm3 PM2_5_CF_ATM_ugm3 Total_PM Temperature_F Safe;
run;
proc corr data=projdata.PurpleAirData nosimple plots=matrix(nvar=all histogram);
	var ADC Created_At Humidity PM10_0_CF_ATM_ugm3 PM1_0_CF_ATM_ugm3 PM2_5_CF_ATM_ugm3 Total_PM Temperature_F;
	with Safe;
run;
*Create scatter plot matrix of IVs; 
proc sgscatter data=projdata.PurpleAirData;
	matrix ADC Created_At Created_At Humidity PM10_0_CF_ATM_ugm3 PM1_0_CF_ATM_ugm3 PM2_5_CF_ATM_ugm3 Total_PM Temperature_F / group=Location_ID;
run;
*Create logistic regression equation using all IVs;
proc logistic data=projdata.PurpleAirData plots(only)=(effect);
	class Safe (param=ref ref='1');
	model Safe(event='1')= ADC location_id Created_At Humidity PM10_0_CF_ATM_ugm3 PM1_0_CF_ATM_ugm3 PM2_5_CF_ATM_ugm3 Total_PM Temperature_F;
run;
quit;
*Figure out which IVs to include/exclude;
proc freq data=projdata.PurpleAirData;
	tables Safe*PM10_0_CF_ATM_ugm3/ chisq;
run;
proc freq data=projdata.PurpleAirData;
	tables Safe*PM1_0_CF_ATM_ugm3/ chisq;
run;
proc freq data=projdata.PurpleAirData;
	tables Safe*PM2_5_CF_ATM_ugm3/ chisq;
run;
proc freq data=projdata.PurpleAirData;
	tables Safe*Total_PM/ chisq;
run;
*Create logistic regression equation using selected IVs;
proc logistic data=projdata.PurpleAirData plots(only)=(effect);
	class Safe (param=ref ref='1');
	model Safe(event='1')= location_id Created_At Humidity Temperature_F;
run;
quit;
*Further narrowing IVs down;
proc logistic data=projdata.PurpleAirData plots(only)=(effect);
	class Safe (param=ref ref='1');
	model Safe(event='1')= location_id Humidity Temperature_F;
run;
quit;
